# Maintainers

- [RDIL](https://github.com/RDIL) *(Team Lead)*
- [CoffeeGoddess](https://github.com/CoffeeGoddess)

# Contributors

Moved [here](https://github.com/area4lib/area4/graphs/contributors).

Thank you for helping out!
